@@ -1,4 +1,4 @@
-/* -*- mode: C -*- Time-stamp: "2010-11-01 16:36:22 jco"
+/* -*- mode: C -*-
  *
  *       File:         rec-mset-type-p.c
  *       Date:         Thu Oct 28 19:55:46 2010
@@ -7,7 +7,7 @@
  *
  */
 
-/* Copyright (C) 2010 Jose E. Marchesi */
+/* Copyright (C) 2010, 2011 Jose E. Marchesi */
 
 /* This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -71,7 +71,8 @@ START_TEST(rec_mset_type_p_existing)
                                  TYPE1,
                                  type1_disp,
                                  type1_equal,
-                                 type1_dup);
+                                 type1_dup,
+                                 NULL);
   
   fail_if (!rec_mset_type_p (mset, type));
   rec_mset_destroy (mset);
@@ -100,7 +101,8 @@ START_TEST(rec_mset_type_p_nonexisting)
                                  TYPE1,
                                  type1_disp,
                                  type1_equal,
-                                 type1_dup);
+                                 type1_dup,
+                                 NULL);
   
   fail_if (rec_mset_type_p (mset, type + 1));
   rec_mset_destroy (mset);
