@@ -22,6 +22,9 @@
 #
 
 : ${srcdir=.}
+: ${builddir=.}
+
+. $builddir/config.sh
 . $srcdir/testutils.sh
 test_init "recfix"
 
@@ -1039,17 +1042,19 @@ test_tool recfix-sortcheck-invalid-field-name xfail \
           '' \
           sortcheck-invalid-field-name
 
+if test "$CRYPT_SUPPORT" = "yes"; then
+
 test_tool recfix-confidential ok \
           recfix \
           '--check' \
           confidential \
-''
+          ''
 
 test_tool recfix-confidential-several ok \
           recfix \
           '--check' \
           confidential-several \
-''
+          ''
 
 test_tool recfix-confidential-with-unencrypted-fields xfail \
           recfix \
@@ -1185,6 +1190,8 @@ joo: encrypted-By/F2HBy1wiim1fUWMVKRg==
 fo: ja
 '
 
+fi # CRYPT_SUPPORT
+
 test_tool recfix-sort-several-fields-invalid xfail \
           recfix \
           '--check' \
