@@ -7,7 +7,7 @@
  *
  */
 
-/* Copyright (C) 2010 Jose E. Marchesi */
+/* Copyright (C) 2010, 2011 Jose E. Marchesi */
 
 /* This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -119,16 +119,6 @@ Convert csv data into rec data.\n"), stdout);
   -e, --omit-empty                    omit empty fields.\n"), stdout);
 
   recutl_print_help_common ();
-
-  puts ("");
-  /* TRANSLATORS: --help output, csv2rec examples.
-     no-wrap */
-  fputs (_("\
-Examples:\n\
-\n\
-        csv2rec contacts.csv > contacts.rec\n\
-        cat contacts.csv | csv2rec > contacts.rec\n"), stdout);
-
   puts ("");
   recutl_print_help_footer ();
 }
@@ -329,7 +319,6 @@ process_csv (void)
 {
   struct csv2rec_ctx ctx;
   FILE *in;
-  FILE *out;
   struct csv_parser p;
   unsigned char options = 0;
   char buf[1024];
@@ -360,8 +349,6 @@ process_csv (void)
       in = stdin;
     }
 
-  out = stdout;
-
   /* Initialize the csv library.  */
   if (csv_init (&p, options) != 0)
     {
