@@ -7,7 +7,7 @@
  *
  */
 
-/* Copyright (C) 2009, 2010 Jose E. Marchesi */
+/* Copyright (C) 2009, 2010, 2011 Jose E. Marchesi */
 
 /* This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,6 +30,7 @@
 #include <stdlib.h>
 #include <gettext.h>
 #define _(str) gettext (str)
+#include <xalloc.h>
 
 #include <rec.h>
 #include <recutl.h>
@@ -119,16 +120,6 @@ If no FILE is specified then the command acts like a filter, getting\n\
 the data from standard input and writing the result to standard output.\n"),
          stdout);
 
-  puts("");
-  /* TRANSLATORS: --help output, recdel examples.
-     no-wrap */
-  fputs (_("\
-Examples:\n\
-\n\
-        recdel -n 10 contacts.rec\n\
-        cat hackers.rec | recdel -e \"Email[0] = 'foo@bar.com'\" > other.rec\n"),
-         stdout);
-  
   puts ("");
   recutl_print_help_footer ();
 }
@@ -192,8 +183,8 @@ recdel_delete_records (rec_db_t db)
           record = rec_rset_elem_record (rec_elem);
           
           if (((recutl_num == -1) && !recutl_sex)
-              || ((recutl_num == -1) &&
-                  ((recutl_sex &&
+              || (((recutl_num == -1) &&
+                   (recutl_sex &&
                     (rec_sex_eval (recutl_sex, record, &parse_status))))
                   || (recutl_num == numrec)))
             {
