@@ -1,4 +1,4 @@
-/* -*- mode: C -*- Time-stamp: "2011-01-31 22:34:52 jemarch"
+/* -*- mode: C -*-
  *
  *       File:         recutl.h
  *       Date:         Thu Apr 22 17:29:52 2010
@@ -183,6 +183,10 @@ void recutl_check_integrity (rec_db_t db,
                              bool verbose_p,
                              bool external_p);
 
+void recutl_sorting_parser (bool sort_p,
+                            char *rset_name,
+                            rec_field_name_t field_name);
+
 #endif /* recutl.h */
 
 /* End of recutl.h */
